@@ -12,7 +12,7 @@ def main():
     cube = GameObject("Cube")
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material((255, 0, 0))
+    renderer.mat = Material(Color(255, 0, 0))
     cube.AddComponent(Rotator)
 
     scene.Add(cube)
