@@ -10,7 +10,7 @@ def main():
     cube.transform.localPosition = Vector3(2, 0, 0)
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material((255, 0, 0))
+    renderer.mat = Material(Color(255, 0, 0))
     collider = cube.AddComponent(AABBoxCollider)
     collider.SetSize(Vector3(1, -1, -1), Vector3(3, 1, 1))
     rb = cube.AddComponent(Rigidbody)
@@ -23,7 +23,7 @@ def main():
     cube.transform.localPosition = Vector3(5, 0, 0)
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material((0, 0, 255))
+    renderer.mat = Material(Color(0, 0, 255))
     collider = cube.AddComponent(AABBoxCollider)
     collider.SetSize(Vector3(4, -1, -1), Vector3(6, 1, 1))
     rb = cube.AddComponent(Rigidbody)
