@@ -5,7 +5,7 @@ class Switch(Behaviour):
     def Update(self, dt):
         self.a -= dt
         if self.a < 0:
-            SceneManager.LoadSceneByIndex(1)
+            SceneManager.LoadSceneByName("Scene 2")
 
 def main():
     scene = SceneManager.AddScene("Scene")
@@ -16,14 +16,14 @@ def main():
     cube = GameObject("Cube")
     renderer = cube.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material((255, 0, 0))
+    renderer.mat = Material(Color(255, 0, 0))
     cube.AddComponent(Switch).scene2 = scene2
     scene.Add(cube)
 
     cube2 = GameObject("Cube 2")
     renderer = cube2.AddComponent(MeshRenderer)
     renderer.mesh = Mesh.cube(2)
-    renderer.mat = Material((0, 0, 255))
+    renderer.mat = Material(Color(0, 0, 255))
     scene2.Add(cube2)
 
     SceneManager.LoadScene(scene)
